@@ -3,7 +3,6 @@
 from hammurabi.config import config
 from hammurabi.law import Law
 from hammurabi.notifications.base import Notification
-from hammurabi.notifications.slack import SlackNotification
 from hammurabi.pillar import Pillar
 from hammurabi.preconditions.attributes import (
     HasMode,
@@ -31,14 +30,6 @@ from hammurabi.rules.files import (
     FilesExist,
     FilesNotExist,
 )
-from hammurabi.rules.ini import (
-    OptionRenamed,
-    OptionsExist,
-    OptionsNotExist,
-    SectionExists,
-    SectionNotExists,
-    SectionRenamed,
-)
 from hammurabi.rules.json import (
     JSONKeyExists,
     JSONKeyNotExists,
@@ -49,12 +40,35 @@ from hammurabi.rules.json import (
 from hammurabi.rules.operations import Copied, Moved, Renamed
 from hammurabi.rules.templates import TemplateRendered
 from hammurabi.rules.text import LineExists, LineNotExists, LineReplaced
-from hammurabi.rules.yaml import (
-    YAMLKeyExists,
-    YAMLKeyNotExists,
-    YAMLKeyRenamed,
-    YAMLValueExists,
-    YAMLValueNotExists,
-)
 
-__version__ = "0.8.0"
+try:
+    from hammurabi.notifications.slack import SlackNotification
+except ImportError:
+    pass
+
+
+try:
+    from hammurabi.rules.ini import (
+        OptionRenamed,
+        OptionsExist,
+        OptionsNotExist,
+        SectionExists,
+        SectionNotExists,
+        SectionRenamed,
+    )
+except ImportError:
+    pass
+
+
+try:
+    from hammurabi.rules.yaml import (
+        YAMLKeyExists,
+        YAMLKeyNotExists,
+        YAMLKeyRenamed,
+        YAMLValueExists,
+        YAMLValueNotExists,
+    )
+except ImportError:
+    pass
+
+__version__ = "0.8.2"
